require 'spec_helper'

describe FriendlyScore do
  subject{ FriendlyScore::API.new 1, "secret" }

  describe "#show" do
    context "with invalid parameters" do
      it "should raise not found error" do
        url = "http://social.friendlyscore.com/api/show.json?appId=1&appSecret=secret&id=1"
        stub_request(:get, url).to_return({
          :status => 404,
          :body => "\{\"code\":404, \"message\":\"some message\"\}"
        })
        
        expect{
          subject.show 1
        }.to raise_error FriendlyScore::Errors::NotFoundError
      end

      it "should raise not found error" do
        url = "http://social.friendlyscore.com/api/show.json?appId=1&appSecret=secret&id=1"
        stub_request(:get, url).to_return({
          :status => 500,
          :body => "\{\"code\":404, \"message\":\"some message\"\}"
        })
        
        expect{
          subject.show 1
        }.to raise_error FriendlyScore::Errors::ServerError
      end
    end

    context "with valid parameters" do
      before :each do
        url = "http://social.friendlyscore.com/api/show.json?appId=1&appSecret=secret&id=1"
        stub_request(:get, url).to_return({
          :status => 200,
          :body => fixture('responses/show.json')
        })
      end

      it "should not raise any error" do
        expect{
          subject.show 1
        }.to_not raise_error
      end

      it "should return instance of user" do
        expect( subject.show 1 ).to be_instance_of FriendlyScore::User
      end

      {
        :id => 1877,
        :status => 2,
        :status_description => "warning",
        :name => "Emilian",
        :age => 29,
        :gender => :male,
        :email => "mind_head@o2.pl",
        :city_name => "London, United Kingdom",
        :family_members_in_home => 1,
        :has_kids => 0,
        :friendlyscore => 49,
        :positive? => true,
        :working? => true,
        :lead? => false
      }.each do |key, value|
        it "should return correct users '#{key}'" do
          expect( subject.show(1).send(key) ).to eq value
        end
      end
    end
  end
end
